@@ -66,7 +66,7 @@ class ApiUnous(UnousRequests):
             if conteudo_integrado > 0:
                 response = self.post(
                     url=url,
-                    json=json.dumps(conteudo_a_integrar, cls=DecimalEncoder),
+                    data=json.dumps(conteudo_a_integrar, cls=DecimalEncoder),
                     headers=self.headers,
                 )
                 if not response.ok:
